<?xml version="1.0" encoding="UTF-8"?>
<!-- custom version for "wissenschaftliches schreiben" -->
<xsl:stylesheet xmlns:elml="http://www.elml.ch" version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format"
  xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:fn="http://www.w3.org/2004/07/xpath-functions"
  xmlns:xdt="http://www.w3.org/2004/07/xpath-datatypes"
  xmlns:fox="http://xml.apache.org/fop/extensions">
  <xsl:import href="../../../core/presentation/print/elml.xsl"/>
  <!-- ***** Parameter definitions  *****-->
  <!--The name of this layout (=folder name of template folder!) -->
  <xsl:param name="layout" select="'wiss-schreiben'"/>
  <!--If you use the latest FOP version enter the value "0.9", otherwise use "0.2" -->
  <xsl:param name="fop_version" select="'0.9'"/>

  <xsl:template match="elml:box">
    <xsl:param name="display">
      <xsl:call-template name="elml:display"/>
    </xsl:param>
    <xsl:if test="$display='yes'">
      <xsl:call-template name="elml:Title"/>
      <fo:block border-style="solid" border-width="1pt" border-color="black" padding="3pt"
        start-indent="{$lineheight}" end-indent="{$lineheight}" space-after="{$lineheight}"
        background-color="lightgrey" margin="5pt">
        <xsl:call-template name="elml:Label"/>
        <xsl:if test="not(@icon)">
          <xsl:attribute name="space-before">
            <xsl:value-of select="$lineheight"/>
          </xsl:attribute>
        </xsl:if>
        <xsl:choose>
          <xsl:when test="@icon">
            <fo:table table-layout="fixed" width="100%" border-style="solid" border-width="0.5pt"
              border-color="white">
              <fo:table-column column-width="40px"/>
              <fo:table-column/>
              <fo:table-body>
                <fo:table-row>
                  <fo:table-cell padding-right="6pt" display-align="before" width="30px">
                    <fo:block>
                      <fo:external-graphic scaling="uniform" content-height="30px"
                        content-width="30px" height="30px" width="30px">
                        <xsl:attribute name="src">
                          <xsl:value-of select="$pathRoot"/>
                          <xsl:text>/_templates/</xsl:text>
                          <xsl:value-of select="$layout"/>
                          <xsl:text>/icons/</xsl:text>
                          <xsl:value-of select="@icon"/>
                          <xsl:text>.</xsl:text>
                          <xsl:value-of select="$icon_filetype"/>
                        </xsl:attribute>
                      </fo:external-graphic>
                    </fo:block>
                  </fo:table-cell>
                  <fo:table-cell padding="3pt" display-align="before">
                    <xsl:apply-templates/>
                  </fo:table-cell>
                </fo:table-row>
              </fo:table-body>
            </fo:table>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates/>
          </xsl:otherwise>
        </xsl:choose>
      </fo:block>
    </xsl:if>
  </xsl:template>
  
  <xsl:template name="elml:generate_Title">
    <xsl:param name="factor">
      <xsl:choose>
        <xsl:when test="name()='lesson'">
          <xsl:text>2.0</xsl:text>
        </xsl:when>
        <xsl:when
          test="name()='unit' or name()='glossary' or name()='index' or name()='bibliography' or name(.)='listOfFigures' or name(.)='listOfTables' or name()='metadata' ">
          <xsl:text>1.6</xsl:text>
        </xsl:when>
        <xsl:when test="name()='learningObject'">
          <xsl:text>1.3</xsl:text>
        </xsl:when>
        <xsl:when test="name()='clarify' or name()='look' or name()='act'">
          <xsl:text>1.0</xsl:text>
        </xsl:when>
        <xsl:when
          test="name()='entry' or name()='goals' or name()='summary' or name()='selfAssessment' or name()='furtherReading'">
          <xsl:choose>
            <xsl:when test="name(parent::*)='lesson'">
              <xsl:text>1.6</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:text>1.3</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:when>
      </xsl:choose>
    </xsl:param>
    <!-- RvW: added if statement -->
    <xsl:if test="name()!='unit' or (name()='unit' and elml:entry)">
      <fo:block line-height="{$fontsize}*{$factor}*1.3" font-size="{$fontsize}*{$factor}"
        font-weight="{$fontweighttitle}" keep-with-next.within-page="always" text-align="left"
        span="all">
        <xsl:attribute name="space-after">
          <xsl:choose>
            <xsl:when test="name()='clarify' or name()='look' or name()='act'">
              <xsl:text>0pt</xsl:text>
            </xsl:when>
            <xsl:otherwise>
              <xsl:value-of select="$lineheight"/>
              <xsl:text>*0.4</xsl:text>
            </xsl:otherwise>
          </xsl:choose>
        </xsl:attribute>
        <xsl:choose>
          <xsl:when
            test="$pagebreak_level='lo' and $factor&gt;1.1 and not(name()='entry' or name()='goals')">
            <xsl:attribute name="break-before">
              <xsl:text>page</xsl:text>
            </xsl:attribute>
          </xsl:when>
          <xsl:when
            test="$pagebreak_level='unit' and $factor&gt;1.4 and not(name()='entry' or name()='goals')">
            <xsl:attribute name="break-before">
              <xsl:text>page</xsl:text>
            </xsl:attribute>
          </xsl:when>
          <xsl:when
            test="$pagebreak_level='lesson' and $factor&gt;1.7 and not(name()='entry' or name()='goals')">
            <xsl:attribute name="break-before">
              <xsl:text>page</xsl:text>
            </xsl:attribute>
          </xsl:when>
          <xsl:otherwise>
            <xsl:attribute name="space-before">
              <xsl:value-of select="$lineheight"/>
              <xsl:text>*0.7*</xsl:text>
              <xsl:value-of select="$factor"/>
            </xsl:attribute>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:call-template name="elml:Label"/>
        <xsl:call-template name="elml:Kapitel"/>
      </fo:block>
    </xsl:if>
    <!-- RvW -->
  </xsl:template>
  
  <xsl:template name="elml:Kapitel_Title">
    <xsl:param name="isnavigation"/>
    <xsl:choose>
      <xsl:when test="(($isnavigation='yes') or ($isnavigation='path_full')) and (@navTitle)">
        <xsl:value-of select="@navTitle"/>
      </xsl:when>
      <xsl:when test="name()='entry' and $isnavigation='yes'">
        <xsl:value-of select="$name_entry"/>
      </xsl:when>
      <xsl:when test="@title">
        <!-- RvW: Fix for units with only one LO: take unit title if LO title is empty -->
        <xsl:choose>
          <xsl:when test="name()='learningObject' and @title=''">
            <xsl:value-of select="../@title"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="@title"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:when>
      <xsl:when test="name()='glossary'">
        <xsl:value-of select="$name_glossary"/>
      </xsl:when>
      <xsl:when test="name()='listOfFigures'">
        <xsl:value-of select="$name_figures"/>
      </xsl:when>
      <xsl:when test="name()='listOfTables'">
        <xsl:value-of select="$name_tables"/>
      </xsl:when>
      <xsl:when test="name()='index'">
        <xsl:value-of select="$name_index"/>
      </xsl:when>
      <xsl:when test="name()='entry'">
        <xsl:value-of select="$name_entry"/>
      </xsl:when>
      <xsl:when test="name()='goals'">
        <xsl:value-of select="$name_lObjectives"/>
      </xsl:when>
      <xsl:when test="name()='summary'">
        <xsl:value-of select="$name_summary"/>
      </xsl:when>
      <xsl:when test="name()='selfAssessment'">
        <xsl:value-of select="$name_selfAssessment"/>
      </xsl:when>
      <xsl:when test="name()='bibliography'">
        <xsl:value-of select="$name_bibliography"/>
      </xsl:when>
      <xsl:when test="name()='furtherReading'">
        <xsl:value-of select="$name_furtherReading"/>
      </xsl:when>
      <xsl:when test="name()='metadata' and $isnavigation='yes'">
        <xsl:value-of select="$name_metadata"/>
      </xsl:when>
      <xsl:when test="name()='metadata'">
        <xsl:value-of select="$name_metadata"/>
        <xsl:text> "</xsl:text>
        <xsl:value-of select="/elml:lesson/@title"/>
        <xsl:text>"</xsl:text>
      </xsl:when>
      <xsl:otherwise>
        <xsl:text>An ERROR occurred, please contact the webmaster! </xsl:text>
        <xsl:value-of select="$contact"/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template name="elml:nav_item">
    <!-- RvW: Fix to suppress superfluous TOC entries for units with only one LO -->
    <xsl:variable name="numlos">
      <xsl:value-of select="number(count(child::*))"/>
    </xsl:variable>
    <xsl:variable name="ancestors">
      <xsl:value-of select="number(count(ancestor-or-self::*))"/>
    </xsl:variable>
    <xsl:variable name="id_nav">
      <xsl:call-template name="elml:Label_param"/>
    </xsl:variable>
    <xsl:if test="name()!='unit' or (name()='unit' and $numlos>1)">
      <fo:block text-align-last="justify" margin-left="{$ancestors}em">
        <fo:basic-link color="black" internal-destination="{$id_nav}">
          <xsl:call-template name="elml:Kapitel"/>
          <xsl:if test="(name()='unit') and contains($optional_units, @label)">
            <xsl:value-of select="$name_optionalunits_symbol"/>
          </xsl:if>
        </fo:basic-link>
        <fo:leader leader-pattern="dots"/>
        <fo:page-number-citation ref-id="{$id_nav}"/>
      </fo:block>
    </xsl:if>
  </xsl:template>
</xsl:stylesheet>
